J_BOOLEAN_PARAM

Enum J_BOOLEAN_PARAM 

#[repr(u32)]
pub enum J_BOOLEAN_PARAM { JBOOLEAN_OPTIMIZE_SCANS = 1_745_618_462, JBOOLEAN_TRELLIS_QUANT = 3_306_299_443, JBOOLEAN_TRELLIS_QUANT_DC = 865_946_636, JBOOLEAN_TRELLIS_EOB_OPT = 3_623_303_040, JBOOLEAN_USE_LAMBDA_WEIGHT_TBL = 865_973_855, JBOOLEAN_USE_SCANS_IN_TRELLIS = 4_253_291_573, JBOOLEAN_TRELLIS_Q_OPT = 3_777_684_073, JBOOLEAN_OVERSHOOT_DERINGING = 1_061_927_929, }
These 32-bit GUIDs and the corresponding jpeg_*_get_*_param() jpeg_*_set_*_param() functions allow for extending the libjpeg API without breaking backward ABI compatibility. The actual parameters are stored in the opaque jpeg_comp_master and jpeg_decomp_master structs.

Variants



JBOOLEAN_OPTIMIZE_SCANS = 1_745_618_462

TRUE=optimize progressive coding scans



JBOOLEAN_TRELLIS_QUANT = 3_306_299_443

TRUE=use trellis quantization



JBOOLEAN_TRELLIS_QUANT_DC = 865_946_636

TRUE=use trellis quant for DC coefficient



JBOOLEAN_TRELLIS_EOB_OPT = 3_623_303_040

TRUE=optimize for sequences of EOB



JBOOLEAN_USE_LAMBDA_WEIGHT_TBL = 865_973_855

TRUE=use lambda weighting table



JBOOLEAN_USE_SCANS_IN_TRELLIS = 4_253_291_573

TRUE=use scans in trellis optimization



JBOOLEAN_TRELLIS_Q_OPT = 3_777_684_073

TRUE=optimize quant table in trellis loop



JBOOLEAN_OVERSHOOT_DERINGING = 1_061_927_929

TRUE=preprocess input to reduce ringing of edges on white background