pub unsafe extern "C-unwind" fn jpeg_crop_scanline(
cinfo: &mut jpeg_decompress_struct,
xoffset: &mut JDIMENSION,
width: &mut JDIMENSION,
)Expand description
This function provides application programmers with the ability to decompress only a portion of each row in the JPEG image. It must be called after jpeg_start_decompress() and before any calls to jpeg_read_scanlines() or jpeg_skip_scanlines(). If the output image is scaled, then xoffset and width are relative to the scaled image dimensions. xoffset and width are passed by reference because xoffset must fall on an iMCU boundary. If it doesn’t, then it will be moved left to the nearest iMCU boundary, and width will be increased accordingly.