pub struct JQUANT_TBL {
pub quantval: [u16; 64],
/* private fields */
}Fields
quantval: [u16; 64]This array gives the coefficient quantizers in natural array order (not the zigzag order in which they are stored in a JPEG DQT marker). CAUTION: IJG versions prior to v6a kept this array in zigzag order.