pub unsafe extern "C-unwind" fn jpeg_skip_scanlines(
cinfo: &mut jpeg_decompress_struct,
num_lines: JDIMENSION,
) -> JDIMENSIONExpand description
This function provides application programmers with the ability to skip over multiple rows in the JPEG image.
Suspending data sources are not supported by this function. Calling jpeg_skip_scanlines() with a suspending data source will result in undefined behavior.